@@ -2,7 +2,7 @@ ACCESS_SLA_TEMPLATE = {
   "type": "Access",
   "templateId": "",
   "name": "dataAssetAccessServiceAgreement",
-  "description": "This service agreement defines the flow for accessing a data asset on the ocean network. Any file or bundle of files can be access using this service agreement",
+  "description": "This service agreement defines the flow for accessing a data asset on the network. Any file or bundle of files can be access using this service agreement",
   "creator": "",
   "serviceAgreementTemplate": {
     "contractName": "AccessTemplate",
